@@ -1,7 +1,7 @@
 package App::hr;
 
-our $DATE = '2015-07-06'; # DATE
-our $VERSION = '0.14'; # VERSION
+our $DATE = '2015-07-20'; # DATE
+our $VERSION = '0.15'; # VERSION
 
 use feature 'say';
 use strict 'subs', 'vars';
@@ -131,7 +131,6 @@ _
             },
         },
     },
-    'cmdline.skip_format' => 1,
 };
 sub hr_app {
     my %args = @_;
@@ -194,7 +193,7 @@ App::hr - Print horizontal bar on the terminal
 
 =head1 VERSION
 
-This document describes version 0.14 of App::hr (from Perl distribution App-hr), released on 2015-07-06.
+This document describes version 0.15 of App::hr (from Perl distribution App-hr), released on 2015-07-20.
 
 =head1 SYNOPSIS
 
@@ -310,7 +309,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/App-hr>.
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-SHARYANTO-Term-Util>.
+Source repository is at L<https://github.com/perlancar/perl-App-hr>.
 
 =head1 BUGS
 
